@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.7.5.
+# This file is part of Merlin, Version: 1.7.7.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -413,7 +413,7 @@ def setup_argparse():
         action="store_true",
         dest="no_errors",
         default=False,
-        help="Flag to ignore some errors for testing.",
+        help="Flag to ignore some flux errors for testing (often used with --dry --local).",
     )
     run.add_argument(
         "--pgen",
